@@ -10,6 +10,7 @@ from sqlalchemy.ext.hybrid import hybrid_method, hybrid_property
 from sqlalchemy.orm import DeclarativeBase, Mapped, mapped_column, relationship
 from sqlalchemy_utils import create_database, database_exists, drop_database  # type: ignore
 
+from dev_utils.sqlalchemy.mixins.audit import AuditMixin
 from dev_utils.sqlalchemy.mixins.general import BetterReprMixin, DictConverterMixin, DifferenceMixin
 from dev_utils.sqlalchemy.types.datetime import UTCDateTime
 from dev_utils.sqlalchemy.types.pydantic import PydanticType
@@ -238,7 +239,7 @@ class OtherModel(Base):  # noqa
         return self.name + "" + self.other_name
 
 
-class TableWithUTCDT(Base):  # noqa: D101
+class TableWithUTCDT(AuditMixin, Base):  # noqa: D101
     __tablename__ = "table_with_UTC_dt"
 
     id: Mapped[int] = mapped_column(primary_key=True)  # noqa
